#ifndef NT2_INCLUDE_FUNCTIONS_ASIND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ASIND_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/asind.hpp>

#endif
